import click

from stumpf.app import create_app
from stumpf.fakes import fake
from stumpf.models import db, Video


@click.command()
@click.option('--only-if-empty', type=click.BOOL, default=False, is_flag=True,
              help='Only generate data if the DB is empty (defaults to false).')
def sample_data(only_if_empty):
    """
    Management script for sample data generation.
    """
    app = create_app({})

    grouper_app = {
        'repo_url': 'https://github.com/Kitware/vaui',
        'name': 'Grouper',
        'url': 'https://mturk.kitware.com/grouper'}
    refiner_app = {
        'repo_url': 'https://github.com/Kitware/refiner',
        'name': 'refiner',
        'url': 'https://mturk.kitware.com/refiner'}

    with app.app_context():
        if only_if_empty and Video.query.first() is not None:
            return

        # Make sure we have a few repeats of url/repo/name
        annotation_apps = [
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**refiner_app),
            fake.stumpf_annotation_app(**refiner_app)]
        annotation_apps.extend([fake.stumpf_annotation_app() for _ in range(4)])

        try:
            for ann_app in annotation_apps:
                db.session.add(ann_app)
                db.session.commit()
                for _ in range(1000):
                    video = fake.stumpf_video()
                    db.session.add(video)
                    db.session.commit()
                    db.session.add_all(fake.stumpf_task(video.id, ann_app.id) for _ in range(10))
                db.session.commit()

        except Exception:
            click.echo('Failed to generate random videos', err=True)
            raise

        click.echo('Inserted 10 apps, 10000 videos and 100000 tasks')


@click.command()
def create_tables():
    app = create_app({})

    with app.app_context():
        db.create_all()
