import os

from faker import Faker
from faker.providers import BaseProvider

from stumpf.models import AnnotationApp, Task, Video

fake = Faker()


class StumpfProvider(BaseProvider):
    def stumpf_video(self):
        path = os.path.dirname(self.generator.file_path(depth=5))
        name = '%s_%s' % (self.generator.random_int(max=999999),
                          self.generator.file_name(category='video'))

        frame_rate = self.generator.random_element(['30', '60', '29.97', '23.976', '24'])
        duration = self.generator.random_int(max=999999, min=1) / float(frame_rate)
        return Video(**{
            'path': f's3:/%s/%s' % (path, name),
            'name': name,
            'frame_rate': frame_rate,
            'duration': duration,
            'width': self.generator.random_element([1280,
                                                    1440,
                                                    1920,
                                                    1024,
                                                    3840,
                                                    1600]),
            'height': self.generator.random_element([800,
                                                     900,
                                                     1200,
                                                     576,
                                                     2160])
        })

    def stumpf_task(self, video_id, annotation_app_id):
        return Task(**{
            'video_id': video_id,
            'hit_id': self.generator.uuid4(),
            'type_': self.generator.random_element({
                'HIT': 0.95,
                'KWIT': 0.05
            }),
            'title': f'{self.generator.word()} Video annotation',
            'description': self.generator.paragraph(),
            'keywords': ','.join(self.generator.words(nb=5)),
            'status': self.generator.random_element(['Assignable', 'Unassignable', 'Reviewable',
                                                     'Reviewing', 'Disposed']),
            'review_status': self.generator.random_element(
                ['NotReviewed', 'MarkedForReview', 'ReviewedAppropriate', 'ReviewedInappropriate']),
            'max_assignments': self.generator.random_int(min=1, max=5),
            'reward': self.generator.random_int(min=10, max=200)
        })

    def stumpf_annotation_app(self, repo_url=None, hash_=None, name=None, url=None):
        return AnnotationApp(**{
            'repo_url': repo_url if repo_url is not None else self.generator.url(),
            'hash': hash_ if hash_ is not None else self.generator.sha1(),
            'name': name if name is not None else f'{self.generator.last_name()} App',
            'url': url if url is not None else self.generator.url()
        })


fake.add_provider(StumpfProvider)
