from flask import jsonify, request
from werkzeug.urls import Href


def paginated_response(query, serialize_fn, default_size=20):
    """
    Paginate a query and generate a response object.

    :param query: A sqlalchemy query object
    :param schema: A marshmallow schema object for serializing the response
    :param default_size: The default page size if none is provided in the request.
    """
    href = Href(request.base_url)
    args = dict(request.args)

    size = request.args.get('size', default_size, int)
    page_number = request.args.get('page', 1, int)
    count = query.count()

    page = query.paginate(page_number, size)

    response = jsonify(serialize_fn(page.items))
    links = []

    args['size'] = size
    args['page'] = 1
    links.append('<%s>; rel="first"' % href(**args))

    if page.has_prev:
        args['page'] = page.prev_num
        links.append('<%s>; rel="prev"' % href(**args))

    if page.has_next:
        args['page'] = page.next_num
        links.append('<%s>; rel="next"' % href(**args))

    if page.pages > 0:
        args['page'] = page.pages
        links.append('<%s>; rel="last"' % href(**args))

    response.headers['Link'] = ', '.join(links)
    response.headers['Resource-Count'] = count
    response.headers['Page-Count'] = page.pages
    return response
