import axios from 'axios';
import cookies from 'js-cookie';
import Raven from 'raven-js';
import RavenVue from 'raven-js/plugins/vue';
import Vue from 'vue';

import App from './App';
import router from './router';
import getToken from './token';

axios.defaults.headers.common['X-Stumpf-Token'] = getToken();

function initialize() {
  axios.get('/api/v1/user/me').then(() => {
    window.App = new Vue({
      el: '#app',
      router,
      components: { App },
      template: '<App/>',
    });
  }).catch(() => {
    window.location.replace('/login');
  });
}

const sentryDSN = cookies.get('stumpf-sentry-dsn');
if (sentryDSN) {
  const release = `${process.env.GITHASH}`;
  Raven
    .config(sentryDSN, {
      release,
      sanitizeKeys: [/[-_]token$/i, /[-_]sensitive[-_]/i, /[-_]auth[-_]/i, /^session$/],
    })
    .addPlugin(RavenVue, Vue)
    .install();

  Raven.context(initialize);
} else {
  initialize();
}
