import createUUID from 'uuid/v4';
import {
  isnil,
  iso8601,
  uuid,
} from 'vue-mc/validation';

import Model from './Model';
import Task from './Task';
import Video from './Video';

class Assignment extends Model {
  constructor(attributes, ...args) {
    const a = Object.assign({}, attributes);
    super(a, ...args);
  }

  defaults() {
    return {
      id: createUUID(),
      created: new Date().toISOString(),
      task_id: createUUID(),
      video_id: createUUID(),
      completed: new Date().toISOString(),
      video: new Video(),
      task: new Task(),
    };
  }

  mutations() {
    return {
      id: id => String(id) || null,
      created: created => new Date(created).toISOString(),
      task_id: id => String(id) || null,
      video_id: id => String(id) || null,
      completed: completed => new Date(completed).toISOString(),
      video: video => new Video(video),
      task: task => new Task(task),
    };
  }

  validation() {
    return {
      id: uuid.or(isnil),
      created: iso8601,
      task_id: uuid.or(isnil),
      video_id: uuid.or(isnil),
      completed: iso8601,
      // video: ,
      // task: ,
    };
  }

  routes() {
    return {
      save: '/api/v1/assignment',
    };
  }
}


export default Assignment;
