import createUUID from 'uuid/v4';
import {
  isnil,
  iso8601,
  required,
  string,
  uuid,
} from 'vue-mc/validation';

import Model from './Model';

class Task extends Model {
  constructor(attributes, ...args) {
    // Rename the `length` attribute from the server to `duration` to
    // get around a bug in vue-mc.
    //   https://github.com/FiguredLimited/vue-mc/issues/47
    const a = Object.assign({}, attributes);
    super(a, ...args);
  }

  defaults() {
    return {
      id: createUUID(),
      created: new Date().toISOString(),
      name: '',
      type_: '',
    };
  }

  mutations() {
    return {
      id: id => String(id) || null,
      created: created => new Date(created).toISOString(),
      name: String,
      type_: String,
    };
  }

  validation() {
    return {
      id: uuid.or(isnil),
      created: iso8601,
      name: required.and(string),
      type_: required.and(string),
    };
  }

  routes() {
    return {
      save: '/api/v1/task',
    };
  }
}


export default Task;
