import createUUID from 'uuid/v4';
import {
  integer,
  isnil,
  iso8601,
  number,
  positive,
  required,
  string,
  uuid,
} from 'vue-mc/validation';

import Model from './Model';

class Video extends Model {
  defaults() {
    return {
      id: createUUID(),
      created: new Date().toISOString(),
      path: '',
      name: '',
      frame_rate: 0,
      duration: 0,
      width: 0,
      height: 0,
    };
  }

  mutations() {
    return {
      id: id => String(id) || null,
      created: created => new Date(created).toISOString(),
      path: String,
      name: String,
      frame_rate: Number,
      duration: Number,
      width: Number,
      height: Number,
    };
  }

  validation() {
    return {
      id: uuid.or(isnil),
      created: iso8601,
      path: required.and(string),
      name: required.and(string),
      frame_rate: number.and(positive),
      duration: number.and(positive),
      width: integer.and(positive),
      height: integer.and(positive),
    };
  }

  routes() {
    return {
      save: '/api/v1/video',
    };
  }
}

export default Video;
